@@ -228,7 +228,9 @@ class SSHClient(object):
                 return_code = channel.recv_exit_status()
                 return ExecResult(return_code, output, stderr)
             else:
-                stdin, stdout, stderr = self.__ssh.exec_command(cmd,timeout=timeout)
+                channel = self.__ssh.exec_command('bash', get_pty=True)[0].channel
+                channel.set_window_size(200, 200)
+                stdin, stdout, stderr = channel.exec_command(cmd,timeout=timeout)
                 exit_status = stdout.channel.recv_exit_status()
                 std_output = stdout.read().decode()
                 std_err = stderr.read().decode()
